Using specific subclasses
-------------------------

The IMNN is a wrapper for several different subclasses to processes data in different ways. For convenience there are examples of using these classes explicitly.

.. toctree::
   :maxdepth: 2
   :caption: Examples:

   subclasses/SimulatorIMNN/SimulatorIMNN
   subclasses/GradientIMNN/GradientIMNN
   subclasses/NumericalGradientIMNN/NumericalGradientIMNN
   subclasses/AggregatedSimulatorIMNN/AggregatedSimulatorIMNN
   subclasses/AggregatedGradientIMNN/AggregatedGradientIMNN
   subclasses/AggregatedNumericalGradientIMNN/AggregatedNumericalGradientIMNN
   subclasses/DatasetGradientIMNN/DatasetGradientIMNN
   subclasses/DatasetNumericalGradientIMNN/DatasetNumericalGradientIMNN
